APOETC
======
This package is used to calculate an exposure time based on a desired signal to noise ratio. See documentation `here <https://apoexposuretimecalculator.github.io/APOExptime/>`_.

pypi page: https://pypi.org/project/APOExptime/ .
To install, use the command 'pip install APOExptime' 

For examples of the project's use, check the examples folder


Limitations
------------
This package was intented only for the Astrophysical Research Consortium (ARC) 3.5m telescope at the Apache Point Observatory.
The current supported instruments are: Arctic, Arces, DIS, TripleSpec, and NICFPS 
(Instrument names must be capitilized same as shown here)
